==> db4o-5.0-mono.tar.gz: db4o-5.0/src/core/src/core/com/db4o/nativequery/expr/BoolConstExpression.cs <==
/* Copyright (C) 2004 - 2005  db4objects Inc.  http://www.db4o.com

This file is part of the db4o open source object database.

db4o is free software; you can redistribute it and/or modify it under
the terms of version 2 of the GNU General Public License as published
by the Free Software Foundation and as clarified by db4objects' GPL 
interpretation policy, available at
http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
Suite 350, San Mateo, CA 94403, USA.

db4o is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or
FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
for more details.

You should have received a copy of the GNU General Public License along
with this program; if not, write to the Free Software Foundation, Inc.,
59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
namespace com.db4o.nativequery.expr
{
	public class BoolConstExpression : com.db4o.nativequery.expr.Expression
	{
		public static readonly com.db4o.nativequery.expr.BoolConstExpression TRUE = new com.db4o.nativequery.expr.BoolConstExpression
			(true);

		public static readonly com.db4o.nativequery.expr.BoolConstExpression FALSE = new 
			com.db4o.nativequery.expr.BoolConstExpression(false);

		private bool _value;

		private BoolConstExpression(bool value)
		{
			this._value = value;
		}

		public virtual bool value()
		{
			return _value;
		}

		public override string ToString()
		{
			return j4o.lang.JavaSystem.getStringValueOf(_value);
		}

		public static com.db4o.nativequery.expr.BoolConstExpression expr(bool value)
		{
			return (value ? TRUE : FALSE);
		}

		public virtual void accept(com.db4o.nativequery.expr.ExpressionVisitor visitor)
		{
			visitor.visit(this);
		}

		public virtual com.db4o.nativequery.expr.Expression negate()
		{
			return (_value ? FALSE : TRUE);
		}
	}
}

==> db4o-5.5-mono.tar.gz: db4o-5.5/src/core/src/core/com/db4o/nativequery/expr/BoolConstExpression.cs <==
/* Copyright (C) 2004 - 2006  db4objects Inc.  http://www.db4o.com

This file is part of the db4o open source object database.

db4o is free software; you can redistribute it and/or modify it under
the terms of version 2 of the GNU General Public License as published
by the Free Software Foundation and as clarified by db4objects' GPL 
interpretation policy, available at
http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
Suite 350, San Mateo, CA 94403, USA.

db4o is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or
FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
for more details.

You should have received a copy of the GNU General Public License along
with this program; if not, write to the Free Software Foundation, Inc.,
59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
namespace com.db4o.nativequery.expr
{
	public class BoolConstExpression : com.db4o.nativequery.expr.Expression
	{
		public static readonly com.db4o.nativequery.expr.BoolConstExpression TRUE = new com.db4o.nativequery.expr.BoolConstExpression
			(true);

		public static readonly com.db4o.nativequery.expr.BoolConstExpression FALSE = new 
			com.db4o.nativequery.expr.BoolConstExpression(false);

		private bool _value;

		private BoolConstExpression(bool value)
		{
			this._value = value;
		}

		public virtual bool Value()
		{
			return _value;
		}

		public override string ToString()
		{
			return j4o.lang.JavaSystem.GetStringValueOf(_value);
		}

		public static com.db4o.nativequery.expr.BoolConstExpression Expr(bool value)
		{
			return (value ? TRUE : FALSE);
		}

		public virtual void Accept(com.db4o.nativequery.expr.ExpressionVisitor visitor)
		{
			visitor.Visit(this);
		}

		public virtual com.db4o.nativequery.expr.Expression Negate()
		{
			return (_value ? FALSE : TRUE);
		}
	}
}
